vidyut-lipi demo

#

vidyut-lipi is a Sanskrit transliterator.
See the About tab for details.

- Simple
- Multi
- Grid
- Detect
- About

Detected as:

(detect uses simple heuristics and will likely yield false positives. Even so, we have found it useful when building user interfaces.)

vidyut-lipi aims to provide a standard transliterator for the Sanskrit ecosystem. It is implemented in Rust and can be bound to other programming languages as needed. Our source code is available here, and you can file bugs here.

This page demonstrates some of vidyut-lipi's features. It has the following tabs:

- Simple shows a simple transliteration UI.
- Multi transliterates into dozens of scripts at once.
- Grid shows our full mapping grid.
- Detect demonstrates our scheme detector.
- About is this page.